/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.sqladmin.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.util.DateTime;

/**
 * A database instance backup run resource.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Cloud SQL Administration API. For a detailed
 * explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class BackupRun extends GenericJson {

  /**
   * Backup Configuration identifier.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String backupConfiguration;

  /**
   * The due time of this run in UTC timezone in RFC 3339 format, for example
   * 2012-11-15T16:19:00.094Z.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime dueTime;

  /**
   * The time the backup operation completed in UTC timezone in RFC 3339 format, for example
   * 2012-11-15T16:19:00.094Z.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime endTime;

  /**
   * The time the run was enqueued in UTC timezone in RFC 3339 format, for example
   * 2012-11-15T16:19:00.094Z.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime enqueuedTime;

  /**
   * Information about why the backup operation failed. This is only present if the run has the
   * FAILED status.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private OperationError error;

  /**
   * Name of the database instance.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String instance;

  /**
   * This is always sql#backupRun.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * The time the backup operation actually started in UTC timezone in RFC 3339 format, for example
   * 2012-11-15T16:19:00.094Z.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime startTime;

  /**
   * The status of this run.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String status;

  /**
   * Backup Configuration identifier.
   * The value returned may be {@code null}.
   */
  public String getBackupConfiguration() {
    return backupConfiguration;
  }

  /**
   * Backup Configuration identifier.
   * The value set may be {@code null}.
   */
  public BackupRun setBackupConfiguration(String backupConfiguration) {
    this.backupConfiguration = backupConfiguration;
    return this;
  }

  /**
   * The due time of this run in UTC timezone in RFC 3339 format, for example
   * 2012-11-15T16:19:00.094Z.
   * The value returned may be {@code null}.
   */
  public DateTime getDueTime() {
    return dueTime;
  }

  /**
   * The due time of this run in UTC timezone in RFC 3339 format, for example
   * 2012-11-15T16:19:00.094Z.
   * The value set may be {@code null}.
   */
  public BackupRun setDueTime(DateTime dueTime) {
    this.dueTime = dueTime;
    return this;
  }

  /**
   * The time the backup operation completed in UTC timezone in RFC 3339 format, for example
   * 2012-11-15T16:19:00.094Z.
   * The value returned may be {@code null}.
   */
  public DateTime getEndTime() {
    return endTime;
  }

  /**
   * The time the backup operation completed in UTC timezone in RFC 3339 format, for example
   * 2012-11-15T16:19:00.094Z.
   * The value set may be {@code null}.
   */
  public BackupRun setEndTime(DateTime endTime) {
    this.endTime = endTime;
    return this;
  }

  /**
   * The time the run was enqueued in UTC timezone in RFC 3339 format, for example
   * 2012-11-15T16:19:00.094Z.
   * The value returned may be {@code null}.
   */
  public DateTime getEnqueuedTime() {
    return enqueuedTime;
  }

  /**
   * The time the run was enqueued in UTC timezone in RFC 3339 format, for example
   * 2012-11-15T16:19:00.094Z.
   * The value set may be {@code null}.
   */
  public BackupRun setEnqueuedTime(DateTime enqueuedTime) {
    this.enqueuedTime = enqueuedTime;
    return this;
  }

  /**
   * Information about why the backup operation failed. This is only present if the run has the
   * FAILED status.
   * The value returned may be {@code null}.
   */
  public OperationError getError() {
    return error;
  }

  /**
   * Information about why the backup operation failed. This is only present if the run has the
   * FAILED status.
   * The value set may be {@code null}.
   */
  public BackupRun setError(OperationError error) {
    this.error = error;
    return this;
  }

  /**
   * Name of the database instance.
   * The value returned may be {@code null}.
   */
  public String getInstance() {
    return instance;
  }

  /**
   * Name of the database instance.
   * The value set may be {@code null}.
   */
  public BackupRun setInstance(String instance) {
    this.instance = instance;
    return this;
  }

  /**
   * This is always sql#backupRun.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * This is always sql#backupRun.
   * The value set may be {@code null}.
   */
  public BackupRun setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * The time the backup operation actually started in UTC timezone in RFC 3339 format, for example
   * 2012-11-15T16:19:00.094Z.
   * The value returned may be {@code null}.
   */
  public DateTime getStartTime() {
    return startTime;
  }

  /**
   * The time the backup operation actually started in UTC timezone in RFC 3339 format, for example
   * 2012-11-15T16:19:00.094Z.
   * The value set may be {@code null}.
   */
  public BackupRun setStartTime(DateTime startTime) {
    this.startTime = startTime;
    return this;
  }

  /**
   * The status of this run.
   * The value returned may be {@code null}.
   */
  public String getStatus() {
    return status;
  }

  /**
   * The status of this run.
   * The value set may be {@code null}.
   */
  public BackupRun setStatus(String status) {
    this.status = status;
    return this;
  }

}
