/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.sqladmin.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.util.DateTime;

/**
 * An Operations resource contains information about database instance operations such as create,
 * delete, and restart. Operations resources are created in response to operations that were
 * initiated; you never create them directly.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Cloud SQL Administration API. For a detailed
 * explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class InstanceOperation extends GenericJson {

  /**
   * The time this operation finished in UTC timezone in RFC 3339 format, for example
   * 2012-11-15T16:19:00.094Z.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime endTime;

  /**
   * The time this operation was enqueued in UTC timezone in RFC 3339 format, for example
   * 2012-11-15T16:19:00.094Z.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime enqueuedTime;

  /**
   * The error(s) encountered by this operation. Only set if the operation results in an error.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<OperationError> error;

  static {
    // hack to force ProGuard to consider OperationError used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(OperationError.class);
  }

  /**
   * The context for export operation, if applicable.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private ExportContext exportContext;

  /**
   * The context for import operation, if applicable.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private ImportContext importContext;

  /**
   * Name of the database instance.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String instance;

  /**
   * This is always sql#instanceOperation.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * An identifier that uniquely identifies the operation. You can use this identifier to retrieve
   * the Operations resource that has information about the operation.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String operation;

  /**
   * The type of the operation. Valid values are CREATE, DELETE, UPDATE, RESTART, IMPORT, EXPORT,
   * BACKUP_VOLUME, RESTORE_VOLUME.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String operationType;

  /**
   * The time this operation actually started in UTC timezone in RFC 3339 format, for example
   * 2012-11-15T16:19:00.094Z.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime startTime;

  /**
   * The state of an operation. Valid values are PENDING, RUNNING, DONE, UNKNOWN.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String state;

  /**
   * The email address of the user who initiated this operation.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String userEmailAddress;

  /**
   * The time this operation finished in UTC timezone in RFC 3339 format, for example
   * 2012-11-15T16:19:00.094Z.
   * The value returned may be {@code null}.
   */
  public DateTime getEndTime() {
    return endTime;
  }

  /**
   * The time this operation finished in UTC timezone in RFC 3339 format, for example
   * 2012-11-15T16:19:00.094Z.
   * The value set may be {@code null}.
   */
  public InstanceOperation setEndTime(DateTime endTime) {
    this.endTime = endTime;
    return this;
  }

  /**
   * The time this operation was enqueued in UTC timezone in RFC 3339 format, for example
   * 2012-11-15T16:19:00.094Z.
   * The value returned may be {@code null}.
   */
  public DateTime getEnqueuedTime() {
    return enqueuedTime;
  }

  /**
   * The time this operation was enqueued in UTC timezone in RFC 3339 format, for example
   * 2012-11-15T16:19:00.094Z.
   * The value set may be {@code null}.
   */
  public InstanceOperation setEnqueuedTime(DateTime enqueuedTime) {
    this.enqueuedTime = enqueuedTime;
    return this;
  }

  /**
   * The error(s) encountered by this operation. Only set if the operation results in an error.
   * The value returned may be {@code null}.
   */
  public java.util.List<OperationError> getError() {
    return error;
  }

  /**
   * The error(s) encountered by this operation. Only set if the operation results in an error.
   * The value set may be {@code null}.
   */
  public InstanceOperation setError(java.util.List<OperationError> error) {
    this.error = error;
    return this;
  }

  /**
   * The context for export operation, if applicable.
   * The value returned may be {@code null}.
   */
  public ExportContext getExportContext() {
    return exportContext;
  }

  /**
   * The context for export operation, if applicable.
   * The value set may be {@code null}.
   */
  public InstanceOperation setExportContext(ExportContext exportContext) {
    this.exportContext = exportContext;
    return this;
  }

  /**
   * The context for import operation, if applicable.
   * The value returned may be {@code null}.
   */
  public ImportContext getImportContext() {
    return importContext;
  }

  /**
   * The context for import operation, if applicable.
   * The value set may be {@code null}.
   */
  public InstanceOperation setImportContext(ImportContext importContext) {
    this.importContext = importContext;
    return this;
  }

  /**
   * Name of the database instance.
   * The value returned may be {@code null}.
   */
  public String getInstance() {
    return instance;
  }

  /**
   * Name of the database instance.
   * The value set may be {@code null}.
   */
  public InstanceOperation setInstance(String instance) {
    this.instance = instance;
    return this;
  }

  /**
   * This is always sql#instanceOperation.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * This is always sql#instanceOperation.
   * The value set may be {@code null}.
   */
  public InstanceOperation setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * An identifier that uniquely identifies the operation. You can use this identifier to retrieve
   * the Operations resource that has information about the operation.
   * The value returned may be {@code null}.
   */
  public String getOperation() {
    return operation;
  }

  /**
   * An identifier that uniquely identifies the operation. You can use this identifier to retrieve
   * the Operations resource that has information about the operation.
   * The value set may be {@code null}.
   */
  public InstanceOperation setOperation(String operation) {
    this.operation = operation;
    return this;
  }

  /**
   * The type of the operation. Valid values are CREATE, DELETE, UPDATE, RESTART, IMPORT, EXPORT,
   * BACKUP_VOLUME, RESTORE_VOLUME.
   * The value returned may be {@code null}.
   */
  public String getOperationType() {
    return operationType;
  }

  /**
   * The type of the operation. Valid values are CREATE, DELETE, UPDATE, RESTART, IMPORT, EXPORT,
   * BACKUP_VOLUME, RESTORE_VOLUME.
   * The value set may be {@code null}.
   */
  public InstanceOperation setOperationType(String operationType) {
    this.operationType = operationType;
    return this;
  }

  /**
   * The time this operation actually started in UTC timezone in RFC 3339 format, for example
   * 2012-11-15T16:19:00.094Z.
   * The value returned may be {@code null}.
   */
  public DateTime getStartTime() {
    return startTime;
  }

  /**
   * The time this operation actually started in UTC timezone in RFC 3339 format, for example
   * 2012-11-15T16:19:00.094Z.
   * The value set may be {@code null}.
   */
  public InstanceOperation setStartTime(DateTime startTime) {
    this.startTime = startTime;
    return this;
  }

  /**
   * The state of an operation. Valid values are PENDING, RUNNING, DONE, UNKNOWN.
   * The value returned may be {@code null}.
   */
  public String getState() {
    return state;
  }

  /**
   * The state of an operation. Valid values are PENDING, RUNNING, DONE, UNKNOWN.
   * The value set may be {@code null}.
   */
  public InstanceOperation setState(String state) {
    this.state = state;
    return this;
  }

  /**
   * The email address of the user who initiated this operation.
   * The value returned may be {@code null}.
   */
  public String getUserEmailAddress() {
    return userEmailAddress;
  }

  /**
   * The email address of the user who initiated this operation.
   * The value set may be {@code null}.
   */
  public InstanceOperation setUserEmailAddress(String userEmailAddress) {
    this.userEmailAddress = userEmailAddress;
    return this;
  }

}
